@@ -1,9 +1,9 @@
 package gnu.crypto.cipher;
 
 // ----------------------------------------------------------------------------
-// $Id: Serpent.java,v 1.7 2002/12/30 05:35:49 rsdio Exp $
+// $Id: Serpent.java,v 1.9 2005/10/06 04:24:14 rsdio Exp $
 //
-// Copyright (C) 2001, 2002, Free Software Foundation, Inc.
+// Copyright (C) 2001, 2002, 2003, Free Software Foundation, Inc.
 //
 // This file is part of GNU Crypto.
 //
@@ -21,8 +21,8 @@ package gnu.crypto.cipher;
 // along with this program; see the file COPYING.  If not, write to the
 //
 //    Free Software Foundation Inc.,
-//    59 Temple Place - Suite 330,
-//    Boston, MA 02111-1307
+//    51 Franklin Street, Fifth Floor,
+//    Boston, MA 02110-1301
 //    USA
 //
 // Linking this library statically or dynamically with other modules is
@@ -77,15 +77,13 @@ import java.util.Iterator;
  *    Candidate Block Cipher for the Advanced Encryption Standard.</a></li>
  * </ol>
  *
- * @version $Revision: 1.7 $
+ * @version $Revision: 1.9 $
  */
 public class Serpent extends BaseCipher {
 
    // Constants and variables
    // -------------------------------------------------------------------------
 
-   private static final String NAME = "serpent";
-
    private static final int DEFAULT_KEY_SIZE = 16;
    private static final int DEFAULT_BLOCK_SIZE = 16;
    private static final int ROUNDS = 32;
